;  ------------------------------------------------------------------

;  These are shortened versions of the procedures used in the article.
;  The full versions are in LookEdit.Sc.

;  ------------------------------------------------------------------

Proc Lookup_Select(edit_is_allowed)

Private p1,p2,x     ;prompt lines and keystroke character

;  Press [F1] and see if it places us into lookup-help

Help                                      ;press [F1]
If helpmode()<>"LookupHelp" then          ;no, it's not lookup help
   If helpmode()="Help" then Esc Endif    ;it's regular help; escape from it
   Beep Return "[F1] is not available for this field."  ;can't press [F1]
Endif

;  Set up the lookup-help environment

p1 = "Move to the record you want to select"
If edit_is_allowed then
   p2 = "Press [F2] to select the record; [Esc] to cancel; [F9] to edit"
Else 
   p2 = "Press [F2] to select the record; [Esc] to cancel"
Endif
Prompt p1,p2
Echo Normal

;  Let the user press keys until pressing one which exits from lookup-help

While helpmode()<>"None"               ;while still in look-up help
   x = getchar()                       ;let the user press a key
   Switch
      Case x=15 or x=-24 or x=-59:     ;[Ctrl-O], [Alt-O], [F1] are illegal
         Beep                          ;... so ignore them
      Case x=-67 and edit_is_allowed:  ;[F9] to edit the lookup table
         Lookup_Edit()                 ;edit the lookup table         
         Prompt p1,p2
      Case x=-67:       Beep           ;[F9] when it's not allowed
      Otherwise:        KeyPress x     ;perform it
   EndSwitch
EndWhile

;  All done

Echo Off
Prompt
Return ""

EndProc

;  ------------------------------------------------------------------

Proc Lookup_Edit()

Private lut, lutkey, origt

;  Remember the current location of the cursor within the lookup table

Echo Off                   ;don't show the user what's going on
lut = upper(table())       ;get the lookup-table name
CtrlHome Right             ;move to the key field column
lutkey = []                ;remember the current key value

;  Switch from lookup mode to the lookup table's image

Esc                           ;escape from lookup-help
origt = table()               ;get the original table name
MoveTo lut                    ;switch to the lookup table image

;  Let the user edit the lookup table

CtrlHome Right                ;move to the key field column
Locate lutkey                 ;move to the same record
Prompt "Edit the "+lut+" lookup table","Press [F2] when done"
Wait Table Until "F2"
CtrlHome Right                ;move to the key field column
lutkey = []                   ;remember the current key value

;  Return to the original table, and resume lookup-help

MoveTo origt                  ;return to the original table
FormKey                       ;return to the form
Help                          ;return to lookup-help
Locate lutkey              ;return to the original record
Echo Normal                   ;resume echoing

EndProc

;  ------------------------------------------------------------------

;  A simple script to test the Lookup_Select() and Lookup_Edit()
;  procedures.

View "Customer"      ;place the lookup table on the workspace
CoEdit "Rental"      ;view the main table, begin co-editing
FormKey              ;switch to the form

While True           ;repeat the "Wait" command till the user presses [F2]
   Wait Table        ;let the user edit the table 
      Prompt "Edit the Rental Table","[F2]=Do-it!  [F1]=LookupHelp"
      Until "F2","F1"

   Switch
      Case retval="F2":    QuitLoop    ;all done
      Case retval="F1": 
         edit_is_allowed =             ;editing the lookup table is allowed
            (field()="Customer #")     ;on the Customer # field
         Lookup_Select(edit_is_allowed)         ;the [F1] lookup process
   EndSwitch
EndWhile

Do_it!         ;end the edit process

;  ------------------------------------------------------------------


